/*
A copyright statement is attached to every file and product created for the
project.  It takes the form of the copyright statement for this 
document:

The project provides a modern way to design and knit garments
using domestic and semi-professional knitting machines.  This document
describes the LockController hardware.

Copyright (C) 2020 Owen Mace and Odile Lambert

This document is free information: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by the
Free Software Foundation, either version 3 of the License, or (at your
option) any later version.

This program is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
this program.  If not, see <https://www.gnu.org/licenses/>.
*/
/*
This is the Yarn Mast support for the Designer Knit counter
for an E6000 knitting machine.

Attachment module dimensions:
  ModuleLength  = 15.2; //X direction
  ModuleWidth   = 13.0; //Y direction
  ModuleHeight  = 28.0; //Z direction

All measurements are in mm
*/

$fn = 50;
Tolerance = 0.2;
//Measured counter dimensions
DAKX = 45.75 + Tolerance * 2;
DAKY = 19.71 + Tolerance * 2;
DAKZ = 31.04;
WallThick = 2;
GussetThick = 3;
Gap = 2;

include </home/owen/Passap/3D Models/Yarn Mast Module/Yarn Mast Module.scad>

YarnMastAttachment();

translate([ -5, 0, 0])
  cube([ 5, ModuleWidth + Gap + DAKY + WallThick * 2, ModuleHeight]);
translate([ -10, ModuleWidth + Gap, ModuleHeight - 5])
  cube([ DAKX + WallThick * 2, DAKY + WallThick * 2, 5]);
//Side walls for Counter
translate([ -10, ModuleWidth + Gap, ModuleHeight])
  cube([ DAKX + WallThick, WallThick, DAKZ / 2]);
translate([ -10, ModuleWidth + Gap + DAKY + WallThick, ModuleHeight])
  cube([ DAKX + WallThick * 2, WallThick, 5]);
translate([ 5, ModuleWidth + Gap + DAKY + WallThick, ModuleHeight])
  cube([ DAKX - 20, WallThick, DAKZ / 2]);
//End walls
translate([ -10, ModuleWidth + Gap + WallThick, ModuleHeight])
  cube([ WallThick, DAKY, 5]);
translate([ DAKX + WallThick  - 10, ModuleWidth + Gap, ModuleHeight])
  cube([ WallThick, DAKY + WallThick, 5]);
//Gusset
translate([ 0, ModuleWidth + Gap + DAKY / 2 + GussetThick / 2 + WallThick, 0])
rotate([ 90, 0, 0])
linear_extrude( height = GussetThick)
{
  polygon( GussetPoints, paths = [ 0, 1, 2, 3, 4], 10);
}
GussetPoints = 
  [[ 0,                            0], 
   [ DAKX - 10 - ModuleHeight / 2, 0],
   [ DAKX - 10 + WallThick * 2,    ModuleHeight - 5],
   [ 0,                            ModuleHeight - 5],
   [ 0, 0]];
